Learn R Programming

georefdatar (version 0.6.5)

ICS_Colors: The CGMW ICS color codes

Description

A data set containing the color codes used by the International Chronostratigraphic Chart by the International Commission on Stratigraphy (ICS) Cohen2013georefdatar.

Usage

ICS_Colors

Arguments

Format

A data frame with 194 rows and the following 11 columns:

standard sorting order

ICS' ordering of this entry

Long List (isc:)

Entries name prefixed by ics:

Long List (formatted)

The (common) name of entry, e.g. 'Holocene'

Rank

Is the entry a System, Series, Stage, ...

Cyan, Magenta, Yellow, Black

Color's values in the CMYK color model

Red, Green, Blue

Color's values in the RGB color model

Details

The coloring in this chart follows the Commission for the Geological Map of the World (CGMW) Vrielynck2022georefdatar.

References

Cohen2013georefdatarVrielynck2022georefdatar

See Also

icsColor() a convenience function to get a specific color.