Learn R Programming

georefdatar (version 0.6.5)

PGE: Platinum-group elements -- PGE

Description

Ru-Pd and Os-Pt: in chemistry, this group is referred to as the platinum metals. Since the 1960 geologists are using the term "platinum-group elements" (PGE) Marshall1999,Connelly2005georefdatar. In geochemistry, this group is further divided into two subgroups: Ir-PGE and Pd-PGE Marshall1999georefdatar with Au often added to the latter Rollinson1993georefdatar.

  • PGE Platinum-group elements -- e.g. Marshall1999georefdatar.

  • IPGE, PPGE Ir-PGE and Pd-PGE -- Rollinson1993,Marshall1999georefdatar;

Usage

PGE

IPGE

PPGE

Arguments

Format

character vector with 6 elements.

character vector with 3 elements.

character vector with 3 elements.

Functions

  • IPGE: Ir-PGE subgroup

  • PPGE: Pd-PGE subgroup

References

Rollinson1993georefdatar

Marshall1999georefdatar

Connelly2005georefdatar

Examples

Run this code
# get information from the periodic table of elements
subset(pte, Symbol %in% PGE)

Run the code above in your browser using DataLab