Learn R Programming

georefdatar (version 0.6.5)

aw: Get the atomic weight of an element

Description

Get the atomic weight of an element

Usage

aw(sym, dataSource = "IUPAC")

Value

Atomic weight of element with the given symbol

Arguments

sym

symbol of the element as a string

dataSource

the data source for the atomic weight, either IUPAC (default) or PubChem. This is case insensitive ("IUPAC" is the same as e.g. "IuPaC")

See Also

IUPAC_StdAW for the table of standard atomic weights by IUPAC and pte for a full periodic table of elements

Examples

Run this code
aw('H')
aw('H')*2+aw('O')

aw('Li', dataSource= "pubchem")

Run the code above in your browser using DataLab