| decayConstants | R Documentation |
A data set containing some decay constants regular used in earth science and geochronology.
decayConstants
A data frame with 6 rows and the following
5 columns:
name of the radioactive isotope – element symbol and mass number
value it's value and
err uncertainty as given by the reference. Uncertainty may be NA if not stated.
unit of the decay – usually per year (y), in some cases per day (d)
refkey key to reference. Also makes the entry in this table unique if there is more than one decay constant per isotope
The following decay constants are included:
Ar37
Ar39
K40
Rb87
Some of them are included more than once in this table because their values changed over time.
Stoenner1965georefdatar
\insertRefSteiger1977georefdatar
\insertRefRenne2001georefdatar
\insertRefRenne2011georefdatar
\insertRefVilla2015georefdatar
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.