Learn R Programming

georefdatar (version 0.6.5)

icsColor: Get ICS Color for a unit name found in the International Chronostratigraphic Chart.

Description

Retrieve the color code for a given name of an eontheme, eratheme, system, ... from the color codes of the International Chronostratigraphic Chart.

Usage

icsColor(name, colorModel = "RGB")

Value

list of the color code in the chosen color model

Arguments

name

character. The name of a unit: eontheme to stage

colorModel

character. The color model to get the color codes in -- either 'RGB' (default) or 'CMYK'.

See Also

ICS_Colors for the full color code table

Examples

Run this code
# Color codes of the Permian in RGB
icsColor("Permian")


Run the code above in your browser using DataLab