Learn R Programming

georefdatar (version 0.6.5)

isoRatios: Isotopic rations

Description

A data set containing some isotopic ratios regular used in earth science

Usage

isoRatios

Arguments

Format

A data frame with 3 rows and the following 4 columns:

  1. name of the isotopic ratio -- twice the element symbol and mass number

  2. value it's value and

  3. err uncertainty as given by the reference. Uncertainty may be NA if not stated.

  4. refkey key to reference. Also makes the entry in this table unique if there is more than one ratio for the isotopes

The following isotopic ratios are included:

  • Ar40Ar36

  • U238U235

Some of them are included more than once in this table because their values changed over time or are still under discussion.

References

Steiger1977georefdatarLee2006georefdatarHiess2012georefdatar