Learn R Programming

georefdatar (version 0.6.5)

pte: Periodic Table of Elements

Description

The periodic table of elements as given by PubChem pubChemPTable;textualgeorefdatar.

Usage

pte

Arguments

Format

A data frame with 118 rows and 17 columns.
For each element the following attributes are reported: AtomicNumber, Symbol, Name, AtomicMass, CPKHexColor, ElectronConfiguration, Electronegativity, AtomicRadius, IonizationEnergy, ElectronAffinity, OxidationStates, StandardState, MeltingPoint, BoilingPoint, Density, GroupBlock, YearDiscovered

References

pubChemPTablegeorefdatarKim_2020georefdatar

See Also

IUPAC_StdAW for the standard atomic weights of the elements recommended by IUPAC