A data set containing the color codes used by the International Chronostratigraphic Chart by the International Commission on Stratigraphy (ICS) Cohen2013georefdatar.
ICS_ColorsA data frame with 194 rows and the following
11 columns:
ICS' ordering of this entry
Entries name prefixed by ics:
The (common) name of entry, e.g. 'Holocene'
Is the entry a System, Series, Stage, ...
Color's values in the CMYK color model
Color's values in the RGB color model
The coloring in this chart follows the Commission for the Geological Map of the World (CGMW) Vrielynck2022georefdatar.
Cohen2013georefdatarVrielynck2022georefdatar
icsColor() a convenience function to get a specific color.