Ru-Pd and Os-Pt: in chemistry, this group is referred to as the platinum
metals. Since the 1960 geologists are using the term "platinum-group
elements" (PGE) Marshall1999,Connelly2005georefdatar. In
geochemistry, this group is further divided into two subgroups: Ir-PGE and
Pd-PGE Marshall1999georefdatar with Au often added to the
latter Rollinson1993georefdatar.
PGE Platinum-group elements -- e.g.
Marshall1999georefdatar.
IPGE, PPGE Ir-PGE and Pd-PGE --
Rollinson1993,Marshall1999georefdatar;