List of rare earth elements and subsets thereof.
REELanthanides
LREE
MREE
HREE
REM
character vector with 15 elements.
character vector with 15 elements.
character vector with 4 elements.
character vector with 6 elements.
character vector with 4 elements.
character vector with 17 elements.
Lanthanides: Only lanthanides
LREE: Light REE subset of REE
MREE: Intermediate REE subset of REE
HREE: Heavy REE subset of REE
REM: Rare earth metals
The "Red Book" Connelly2005georefdatar defines the
rare earth metals (REM) as Sc, Y and the lanthanides (La -- Lu). In
geochemistry, the term "rare earth elements" is generally limited to the
lanthanides -- e.g. Rollinson1993,Marshall1999georefdatar.
Therefore, it is crucial to consider the context in which this term is
used.
A distinction is made here between rare earth metals (REM) and
rare earth elements (REE). The latter are the lanthanides as they are
commonly used in geochemistry. Speaking in sets, the REE are a subset of
the REM. And all subsets of the REE are also limited to the lanthanides.
Lanthanides La--Lu Connelly2005georefdatar.
REE Same as Lanthanides. The term rare earth elements as used in geochemistry -- e.g Rollinson1993,Marshall1999georefdatar.
REM Rare earth metals. Sc, Y and the lanthanides Connelly2005georefdatar
LREE Light REE, La--Nd
MREE Intermediate REE, Sm--Ho
HREE Heavy REE, Er--Lu
Rollinson1993georefdatar
Marshall1999georefdatar
Connelly2005georefdatar
# get information from the periodic table of elements
subset(pte, Symbol %in% REE)
Run the code above in your browser using DataLab