powered by
Get the atomic weight of an element
aw(sym, dataSource = "IUPAC")
Atomic weight of element with the given symbol
symbol of the element as a string
the data source for the atomic weight, either IUPAC (default) or PubChem. This is case insensitive ("IUPAC" is the same as e.g. "IuPaC")
IUPAC
PubChem
IUPAC_StdAW for the table of standard atomic weights by IUPAC and pte for a full periodic table of elements
aw('H') aw('H')*2+aw('O') aw('Li', dataSource= "pubchem")
Run the code above in your browser using DataLab