A data set containing some decay constants regular used in earth science and geochronology.
decayConstantsA data frame with 6 rows and the following
5 columns:
name of the radioactive isotope -- element symbol and mass number
value it's value and
err uncertainty as given by the reference. Uncertainty may be NA if not stated.
unit of the decay -- usually per year (y), in some cases per day (d)
refkey key to reference. Also makes the entry in this table unique if there is more than one decay constant per isotope
The following decay constants are included:
Ar37
Ar39
K40
Rb87
Some of them are included more than once in this table because their values changed over time.
Stoenner1965georefdatarSteiger1977georefdatarRenne2001georefdatarRenne2011georefdatarVilla2015georefdatar