powered by
Retrieve the color code for a given name of an eontheme, eratheme, system, ... from the color codes of the International Chronostratigraphic Chart.
icsColor(name, colorModel = "RGB")
list of the color code in the chosen color model
character. The name of a unit: eontheme to stage
character. The color model to get the color codes in -- either 'RGB' (default) or 'CMYK'.
ICS_Colors for the full color code table
# Color codes of the Permian in RGB icsColor("Permian")
Run the code above in your browser using DataLab